@@ -3,13 +3,15 @@
 from __future__ import annotations
 
 import textwrap
-
-from markupsafe import Markup
+from typing import TYPE_CHECKING, Any
 
 from markdown_exec.formatters.base import base_format
-from markdown_exec.formatters.sh import _run_sh  # noqa: WPS450
+from markdown_exec.formatters.sh import _run_sh
 from markdown_exec.logger import get_logger
 
+if TYPE_CHECKING:
+    from markupsafe import Markup
+
 logger = get_logger(__name__)
 
 
@@ -23,5 +25,5 @@ def _transform_source(code: str) -> tuple[str, str]:
     return sh_code, textwrap.indent(sh_code, prompt)
 
 
-def _format_console(**kwargs) -> Markup:
+def _format_console(**kwargs: Any) -> Markup:
     return base_format(language="console", run=_run_sh, transform_source=_transform_source, **kwargs)
